@@ -69,6 +69,9 @@ class Geometry:
       """Return the k-mesh"""
       from . import klist
       return klist.kmesh(self.dimensionality,**kwargs)
+  def get_default_kpath(self,**kwargs):
+      from . import klist
+      return klist.default(self,**kwargs)
   def set_finite(self,periodic=False):
     """ Transfrom the geometry into a finite system"""
     if periodic:
@@ -86,39 +89,9 @@ class Geometry:
       else:
         iis = sculpt.get_closest(self,n=n,r0=r)
         return [self.r[ii] for ii in iis] # return positions
-  def supercell(self,nsuper):
-    """Creates a supercell"""
-    if self.dimensionality==0: return self # zero dimensional
-    if np.array(nsuper).shape==(3,3):
-      return supercelltk.non_orthogonal_supercell(self,nsuper)
-    if self.dimensionality==1:
-      if checkclass.is_iterable(nsuper): nsuper = nsuper[0]
-      return supercell1d(self,nsuper)
-    elif self.dimensionality==2:
-      try: # two numbers given
-        nsuper1 = nsuper[0]
-        nsuper2 = nsuper[1]
-      except: # one number given
-        nsuper1 = nsuper
-        nsuper2 = nsuper
-      if abs(nsuper1-np.round(nsuper1))>1e-6 or abs(nsuper2-np.round(nsuper2))>1e-6:
-          return supercelltk.target_angle_volume(self,angle=None,
-                  volume=nsuper1*nsuper2)
-      else: return supercell2d(self,n1=nsuper1,n2=nsuper2)
-    elif self.dimensionality==3:
-      try: # two number given
-        nsuper1 = nsuper[0]
-        nsuper2 = nsuper[1]
-        nsuper3 = nsuper[2]
-      except: # one number given
-        nsuper1 = nsuper
-        nsuper2 = nsuper
-        nsuper3 = nsuper
-      s = supercell3d(self,n1=nsuper1,n2=nsuper2,n3=nsuper3)
-    else: raise
-    s.center()
-    s.get_fractional()
-    return s
+  def get_supercell(self,nsuper):
+      return get_supercell(self,nsuper)
+  supercell = get_supercell # backwards compatibility
   def xyz2r(self):
     """Updates r atributte according to xyz"""
     self.r = np.array([self.x,self.y,self.z]).transpose()
@@ -1653,3 +1626,40 @@ from .sculpt import image2island
 from .geometrytk import readgeometry 
 read_xyz = readgeometry.read_xyz
 
+
+
+def get_supercell(self,nsuper):
+    """Creates a supercell"""
+    if self.dimensionality==0: return self # zero dimensional
+    if np.array(nsuper).shape==(3,3):
+      return supercelltk.non_orthogonal_supercell(self,nsuper)
+    if self.dimensionality==1:
+      if checkclass.is_iterable(nsuper): nsuper = nsuper[0]
+      return supercell1d(self,nsuper)
+    elif self.dimensionality==2:
+      try: # two numbers given
+        nsuper1 = nsuper[0]
+        nsuper2 = nsuper[1]
+      except: # one number given
+        nsuper1 = nsuper
+        nsuper2 = nsuper
+      if abs(nsuper1-np.round(nsuper1))>1e-6 or abs(nsuper2-np.round(nsuper2))>1e-6:
+          return supercelltk.target_angle_volume(self,angle=None,
+                  volume=nsuper1*nsuper2)
+      else: return supercell2d(self,n1=nsuper1,n2=nsuper2)
+    elif self.dimensionality==3:
+      try: # two number given
+        nsuper1 = nsuper[0]
+        nsuper2 = nsuper[1]
+        nsuper3 = nsuper[2]
+      except: # one number given
+        nsuper1 = nsuper
+        nsuper2 = nsuper
+        nsuper3 = nsuper
+      s = supercell3d(self,n1=nsuper1,n2=nsuper2,n3=nsuper3)
+    else: raise
+    s.center()
+    s.get_fractional()
+    return s
+
+
