@@ -50,8 +50,8 @@ def valence_TMDC(g=None,soc=0.0,**kwargs):
     """Return the Hamiltonian for the valence band of a TMDC"""
     if g is None:
         g = geometry.triangular_lattice()
-    ft = specialhopping.phase_C3_matrix(g,phi=soc,**kwargs)
-    h = g.get_hamiltonian(mgenerator=ft,is_multicell=True,has_spin=False)
+    ft = specialhopping.phase_C3(g,phi=soc,**kwargs)
+    h = g.get_hamiltonian(fun=ft,is_multicell=True,has_spin=False)
     h.turn_spinful(enforce_tr=True)
     return h # return the Hamiltonian
 
@@ -70,19 +70,19 @@ def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0]):
     if g is None: 
         g = geometry.triangular_lattice()  # triangular lattice
         if cdw!=0.0: g = g.supercell(3)
+#    ts = [1.0,0.3,0.6]
     ts = np.array(ts)
-    t = ts[0]/np.max(ts) # 1NN 
+#    t = ts[0]/np.max(ts) # 1NN 
     ts = ts/np.max(ts) # normalize
-    fm = specialhopping.neighbor_hopping_matrix(g,ts) # function for hoppings
-    h = g.get_hamiltonian(mgenerator=fm,is_multicell=True,has_spin=False,
-            cutoff=len(ts))
+#    fm = specialhopping.neighbor_hopping_matrix(g,ts) # function for hoppings
+    h = g.get_hamiltonian(is_multicell=True,has_spin=False,ts=ts)
     ## Now add the SOC if necessary
     if soc!=0.0: # add the SOC
         h.turn_spinful() # turn spinful
         d = g.neighbor_distances()[1]
         d = 1.0
         hsoc = valence_TMDC(g=h.geometry,soc=soc,d=d) # hamiltonian with SOC
-        h = h + t*hsoc # add the two Hamiltonians
+        h = h + hsoc # add the two Hamiltonians
     if cdw!=0.0: # add the CDW
         g0 = geometry.triangular_lattice()  # triangular lattice
         g0 = g0.supercell(3) # create a supercell
